@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2012-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -53,6 +53,7 @@
 ##     ''     Also delay a bit if write intf2 = UNO to avoid unzip errors
 ## 2014-01-01 Provisionally fall back to COM or POI for intf2
 ##     ''     Provide default test file name
+## 2015-03-06 Replace deprecated strmatch
 
 function io_xls_testscript (intf, fname="io-test.xls", intf2=[])
 
@@ -119,7 +120,7 @@ function io_xls_testscript (intf, fname="io-test.xls", intf2=[])
   if (isuno)
     sleep (dly);
   endif
-  shnr = strmatch ('Testsheet', shts(:, 1));      ## Note case!
+  shnr = find (strcmp ('Testsheet', shts(:, 1)));      ## Note case!
   if (isempty (shnr))
     printf ("Worksheet with data not found - not properly written ... test failed.\n");
     return
