@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -23,7 +23,7 @@
 ## in an OpenOffice_org Calc or Gnumeric spreadsheet file pointed to
 ## in struct @var{ods}.
 ##
-## @var{ods} is supposed to have been created earlier by odsopen in the
+## @var{ods} is supposed to have been created earlier by odsopen() in the
 ## same octave session.
 ##
 ## @var{wsh} is either numerical or text, in the latter case it is 
@@ -133,8 +133,8 @@
 ## 2013-12-27 More style fixes
 ## 2014-04-13 Copyright string updated
 ## 2014-04-15 More updates to texinfo header
-##
-## Latest subfunc update: 2012-10-12
+## 2015-03-06 Texinfo header update
+##     ''     Add "\n" to error messages to suppress traceback
 
 function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=[])
 
@@ -147,15 +147,15 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
   test1 = test1 || isempty (ods.workbook);
   test1 = test1 || isempty (ods.app);
   if (test1)
-    error ("Arg #1 is an invalid ods file struct");
+    error ("Arg #1 is an invalid ods file struct\n");
   endif
   ## Check worksheet ptr
   if (! (ischar (wsh) || isnumeric (wsh)))
-    error ("Integer (index) or text (wsh name) expected for arg # 2");
+    error ("Integer (index) or text (wsh name) expected for arg # 2\n");
   endif
   ## Check range
   if (! (isempty (datrange) || ischar (datrange)))
-    error ("Character string (range) expected for arg # 3");
+    error ("Character string (range) expected for arg # 3\n");
   endif
   ## Check & setup options struct
   if (nargin < 4 || isempty (spsh_opts))
@@ -164,7 +164,7 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
     ## Other options here:
 
   elseif (! isstruct (spsh_opts))
-    error ("struct expected for OPTIONS argument (# 4)");
+    error ("struct expected for OPTIONS argument (# 4)\n");
   else
     if (! isfield (spsh_opts, "formulas_as_text"))
       spsh_opts.formulas_as_text = 0;
@@ -185,7 +185,7 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
       case {"0.8.6", "0.8.7", "0.8.8"}
         [rawarr, ods] = __OTK_spsh2oct__ (ods, wsh, datrange, spsh_opts);
       otherwise
-        error ("Unsupported odfdom version or invalid ods file pointer.");
+        error ("Unsupported odfdom version or invalid ods file pointer.\n");
     endswitch
   elseif (strcmp (ods.xtype, "JOD"))
     ## Read ods file tru Java & jOpenDocument. JOD doesn't know about formulas :-(
@@ -205,7 +205,7 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
   ##elseif
   ##  ---- < Other interfaces here >
   else
-    error (sprintf ("ods2oct: unknown OpenOffice.org .ods interface - %s.", ods.xtype));
+    error (sprintf ("ods2oct: unknown OpenOffice.org .ods interface - %s.\n", ods.xtype));
   endif
 
   rstatus = ! isempty (rawarr);
