@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -24,39 +24,42 @@
 ## Calling odsopen without specifying a return argument is fairly useless!
 ##
 ## Octave links to external software for read/write support of spreadsheets;
-## these links are "interfaces". For I/O from/to ODS 1.2 and Gnumeric
+## these links are "interfaces".  For I/O from/to ODS 1.2 and Gnumeric
 ## XML, in principle no external SW is required, this "interface" is called
-## 'OCT'. For more flexibility and better performance, you need a Java JRE
+## 'OCT'.  For more flexibility and better performance, you need a Java JRE
 ## or JDK plus one or more of (ODFtoolkit (version 0.7.5 or 0.8.6 - 0.8.8) &
 ## xercesImpl v.2.9.1), jOpenDocument, or OpenOffice.org (or clones) installed
-## on your computer + proper javaclasspath set. These interfaces are referred
+## on your computer + proper javaclasspath set.  These interfaces are referred
 ## to as OTK, JOD, and UNO resp., and are preferred in that order by default
 ## (depending on their presence; the OCT interface has lowest priority).
 ## The relevant Java class libs for spreadsheet I/O had best be added to the
 ## javaclasspath by utility function chk_spreadsheet_support().
+## For the OTK, JOD and UNO interfaces in Octave older than 3.8.0, the
+## octave-forge Java package >=1.2.9 is required.  Newer Octave versions
+## should have Java support built-in.
 ##
 ## @var{filename} must be a valid .ods OpenOffice.org Calc, or Gnumeric, file
-## name including .ods or .gnumeric suffix. If @var{filename} does not contain
-## any directory path, the file is saved in the current directory. For UNO
+## name including .ods or .gnumeric suffix.  If @var{filename} does not contain
+## any directory path, the file is saved in the current directory.  For UNO
 ## bridge, filenames need to be in the form "file:///<path_to_file>/filename";
 ## a URL will also work. If a plain file name is given (absolute or relative),
-## odsopen() will try to transform it into proper form.
+## odsopen() will try to transform it into a proper form.
 ##
 ## @var{readwrite} must be set to true or numerical 1 if writing to spreadsheet
-## is desired immediately after calling odsopen(). It merely serves proper
+## is desired immediately after calling odsopen().  It merely serves proper
 ## handling of file errors (e.g., "file not found" or "new file created").
 ##
 ## Optional input argument @var{reqintf} can be used to override the ODS
-## interface automatically selected by odsopen. Currently implemented
+## interface automatically selected by odsopen.  Currently implemented
 ## interfaces are 'OTK' (Java/ODF Toolkit), 'JOD' (Java/jOpenDocument), 'UNO'
 ## (Java/OpenOffice.org UNO bridge), and 'OCT' (native Octave, for Gnumeric.
 ## In most situations this parameter is unneeded as odsopen
 ## automatically selects the most useful interface present ("default
-## interface"). Depending on file type, odsopen.m can invoke other detected
+## interface").  Depending on file type, odsopen.m can invoke other detected
 ## interfaces than the default one.
 ##
 ## Beware:
-## The UNO interface is still experimental. While in itself reliable, it may
+## The UNO interface is still experimental.  While in itself reliable, it may
 ## have undesired side effects on Open-/LibreOffice windows outside Octave.
 ##
 ## Examples:
@@ -140,6 +143,9 @@
 ## 2014-04-15 More updates to texinfo header
 ## 2014-04-26 Fix error messages (no more traceback)
 ## 2014-05-01 Write support for gnumeric
+## 2015-03-06 Texinfo header update
+##     ''     Create new files silently
+##     ''     Replace usage() by error(); augment with "\n" to suppress traceback
 
 function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
 
@@ -154,12 +160,12 @@ function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
   odsintf_cnt = 1;
   
   if (nargout < 1)
-    usage ("ODS = odsopen (ODSfile, [Rw]). But no return argument specified!");
+    error ("No return argument specified!\n usage: ODS = odsopen (ODSfile, [Rw]).\n");
   endif
 
   if (! isempty (reqinterface))
     if (! (ischar (reqinterface) || iscell (reqinterface)))
-      usage ("odsopen.m: arg # 3 (interface) not recognized");
+      error ("odsopen.m: arg # 3 (interface) not recognized\n");
     endif
     ## Turn arg3 into cell array if needed
     if (! iscell (reqinterface))
@@ -184,7 +190,7 @@ function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
         elseif (strcmpi (reqintf, "OCT"))
           odsinterfaces.OCT = [];
         else 
-          usage (sprintf (["odsopen.m: unknown .ods interface \"%s\" requested.\n" ...
+          error (sprintf (["odsopen.m: unknown .ods interface \"%s\" requested.\n" ...
                   "Only OTK, JOD, UNO and OCT supported\n"], reqinterface{}));
         endif
       endfor
@@ -234,7 +240,7 @@ function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
       fid = fopen (filename, "rb");  
       ## Check if it can be opened for reading
       if (fid < 0)            ## Not found => create it
-        printf ("Creating file %s\n", filename);
+##      printf ("Creating file %s\n", filename);
         rw = 3;
       else                    ## Found but not writable = error
         fclose (fid);         ## Do not forget to close the handle neatly
