@@ -1,5 +1,5 @@
 ## Copyright (C) 2013,2014 Markus Bergholz
-## Parts Copyright (C) 2014 Philip Nienhuis
+## Parts Copyright (C) 2014-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -82,6 +82,7 @@
 ## 2014-10-26   - Improve rId bookkeeping in _rels
 ## 2014-10-29   - more _rels bookkeepin improvements.
 ##              - Ignore writing empty text cells to worksheet
+## 2015-03-07   - Replace deprecated strmatch
 
 function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_opts, obj_dims)
 
@@ -103,7 +104,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
     if (length (wsh) > 31)
       error ("Worksheet name longer than 31 characters is not supported by Excel\n");
     endif
-    wsh_number = strmatch (wsh, xls.sheets.sh_names, "exact");
+    wsh_number = find (strcmp (wsh, xls.sheets.sh_names));
     if (isempty (wsh_number))
       ## Worksheet not in stack; create a new sheet
       new_sh = 1;
@@ -119,7 +120,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
       ## Default sheet name
       wsh_string = sprintf ("Sheet%d", wsh);
       ## It may already exist...
-      while (! isempty (strmatch (wsh_string, xls.sheets.sh_names)) && ...
+      while (! isempty (find (strcmp (wsh_string, xls.sheets.sh_names))) && ...
              length (wsh_string <= 31))
         wsh_string = strrep (wsh_string, "Sheet", "Sheet_");
       endwhile
@@ -338,7 +339,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
     rid = fopen ([xls.workbook filesep "xl" filesep "_rels" filesep "workbook.xml.rels"], "r+");
     rxml = fread (rid, Inf, "char=>char").';
     fclose (rid);
-    if (isempty (strmatch ("sharedStrings", rxml)))
+    if (isempty (strfind (rxml, "sharedStrings")))
       ## Add sharedStrings.xml entry. First find unique rId
       rId = str2double (cell2mat (regexp (rxml, 'Id="rId(\d+)"', "tokens")));
       nwrId = sort (rId)(end) + 1;
@@ -355,7 +356,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
     tid = fopen ([xls.workbook filesep "[Content_Types].xml"], "r+");
     txml = fread (tid, Inf, "char=>char").';
     fclose (tid);
-    if (isempty (strmatch ("sharedStrings", txml)))
+    if (isempty (strfind (txml, "sharedStrings")))
       ## Add sharedStrings.xml entry after styles.xml node. First find that one
       [~, ~, ipos] = regexp (txml, '(?:styles\+xml)(?:.+)(><Over)', 'once');
       ipos = ipos(1);
@@ -515,7 +516,7 @@ function [ xls, rstatus ] = __OCT_oct2xlsx_sh__ (xls, wsh_number, arrdat, lims,
             case 3                    ## String
                 ttag = ' t="s"';
                 ## FIXME s value provisionally set to 0
-                sptr = strmatch (arrdat{ii, jj}, strings, "exact");
+                sptr = find (strcmp (arrdat{ii, jj}, strings));
                 if (isempty (sptr))
                   ## Add new string
                   strings = [strings arrdat{ii, jj}];
