@@ -76,7 +76,7 @@ function [ raw, xls, rstatus ] = __OCT_xlsx2oct__ (xls, wsh, crange='', spsh_opt
       if (isempty (id))
         error ("xls2oct: cannot find sheet '%s' in file %s", wsh, xls.filename);
       else
-        wsh = xls.sheets.sheetid(id);
+        wsh = id;
       endif
     # endif
   elseif (wsh > numel (xls.sheets.sh_names))
