@@ -147,6 +147,8 @@
 ##     ''     Clarify message about missing I/O support with file extension
 ## 2015-03-06 Clarify some error messages, replace usage() with error
 ##     ''     Be silent when creating new file
+## 2015-04-24 Depending on supported interfaces, use .xls or .xlsx (OOXML)
+##            if no suffix was specified
 
 function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
 
@@ -265,9 +267,10 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
   if (xwrite)
     fmode = 'r+b';
     if (! has_suffix)
-      ## Add .xls suffix to filename (all Excel versions can write this)
+      ## Provisionally add .xls suffix to filename (most used format)
       filename = [filename ".xls"];
       ext = ".xls";
+      ftype = 1
     endif
   else
     fmode = 'rb';
@@ -307,6 +310,15 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
   ## Check for the various Excel interfaces. No problem if they've already
   ## been checked, getxlsinterfaces (far below) just returns immediately then.
   xlsinterfaces = getxlsinterfaces (xlsinterfaces);
+
+  ## If no external interface was detected and no suffix was given, use .xlsx
+  if (! has_suffix && ! (xlsinterfaces.COM + xlsinterfaces.POI + ...
+                         xlsinterfaces.JXL + xlsinterfaces.OXS + ...
+                         xlsinterfaces.UNO))
+    ## Just add 'x' - .xls was already added higher up
+    filename = [filename "x"];
+    ftype = 2;
+  endif
   
   ## Initialize file ptr struct
   xls = struct ("xtype",    'NONE', 
